@@ -896,13 +896,6 @@ class Test_ComputerRolesExceptIpmanagedclient:
 @pytest.mark.parametrize('role', ('computers/domaincontroller_master', 'computers/domaincontroller_slave', 'computers/domaincontroller_backup', 'computers/memberserver'))
 class Test_UCSServerRoles:
 
-    def test_modify_reinstall(self, role, verify_ldap_object, udm):
-        """Test modifying reinstall for computers/domaincontroller_master, computers/domaincontroller_slave, computers/domaincontroller_backup and computers/memberserver"""
-        reinstall = '1'
-        computer = udm.create_object(role, name=random_name())
-        udm.modify_object(role, dn=computer, reinstall=reinstall)
-        verify_ldap_object(computer, {'univentionServerReinstall': [reinstall]})
-
     def test_modify_instprofile(self, udm, verify_ldap_object, role):
         """Test modifying instprofile for computers/domaincontroller_master, computers/domaincontroller_slave, computers/domaincontroller_backup and computers/memberserver"""
         instprofile = random_string()
